@@ -1,17 +1,17 @@
 package OpenGL::Sandbox::ContextShim::GLFW;
-BEGIN { $OpenGL::Sandbox::ContextShim::GLFW::VERSION = '0.041'; }
 use strict;
 use warnings;
 use Carp;
+use Scalar::Util 'weaken';
 use OpenGL::GLFW qw/ glfwInit glfwGetVersionString glfwTerminate NULL GLFW_TRUE GLFW_FALSE
 	glfwGetPrimaryMonitor glfwCreateWindow glfwMakeContextCurrent glfwDestroyWindow
 	glfwSwapInterval glfwSwapBuffers glfwPollEvents
 	glfwWindowHint GLFW_VISIBLE GLFW_DECORATED GLFW_MAXIMIZED GLFW_DOUBLEBUFFER
 	/;
 use OpenGL::Sandbox qw/ glGetString GL_VERSION /;
-use Scalar::Util 'weaken';
 
 # ABSTRACT: Context wrapper around OpenGL::GLFW API
+our $VERSION = '0.042'; # VERSION
 
 # would use Moo, but I want to write my own constructor rather than store
 # all these arguments as official attributes.
@@ -90,7 +90,7 @@ OpenGL::Sandbox::ContextShim::GLFW - Context wrapper around OpenGL::GLFW API
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 DESCRIPTION
 
@@ -110,12 +110,16 @@ Accepting all the options of make_context
 
 =back
 
-=head1 ATTRIBUTES
+It also provides:
 
-=head2 window
+=over 14
+
+=item window
 
 The GLFW window handle
 
+=back
+
 =head1 AUTHOR
 
 Michael Conrad <mike@nrdvana.net>
