@@ -1,10 +1,13 @@
 package OpenGL::Sandbox::ContextShim::GLX;
-BEGIN { $OpenGL::Sandbox::ContextShim::GLX::VERSION = '0.041'; }
-use X11::GLX::DWIM;
-use OpenGL::Sandbox 'glGetString', 'GL_VERSION';
+use strict;
+use warnings;
+use Carp;
 use Scalar::Util 'weaken';
+use OpenGL::Sandbox qw/ glGetString GL_VERSION /;
+use X11::GLX::DWIM;
 
 # ABSTRACT: Subclass of X11::GLX::DWIM to meet contract of OpenGL::Sandbox::make_context
+our $VERSION = '0.042'; # VERSION
 
 our %instances;
 sub new {
@@ -63,7 +66,7 @@ OpenGL::Sandbox::ContextShim::GLX - Subclass of X11::GLX::DWIM to meet contract
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 DESCRIPTION
 
@@ -81,12 +84,16 @@ Accepting all the options of make_context
 
 =back
 
-=head1 ATTRIBUTES
+It also provides:
 
-=head2 glx
+=over 14
+
+=item glx
 
 The L<X11::GLX::DWIM> object
 
+=back
+
 =head1 AUTHOR
 
 Michael Conrad <mike@nrdvana.net>
