@@ -1,10 +1,13 @@
 package OpenGL::Sandbox::ContextShim::SDL;
-BEGIN { $OpenGL::Sandbox::ContextShim::SDL::VERSION = '0.041'; }
-use SDLx::App;
-use OpenGL::Sandbox 'glGetString', 'GL_VERSION';
+use strict;
+use warnings;
+use Carp;
 use Scalar::Util 'weaken';
+use OpenGL::Sandbox qw/ glGetString GL_VERSION /;
+use SDLx::App;
 
 # ABSTRACT: Subclass of SDLx::App to meet contract of OpenGL::Sandbox::make_context
+our $VERSION = '0.042'; # VERSION
 
 my %instances;
 sub new {
@@ -65,7 +68,7 @@ OpenGL::Sandbox::ContextShim::SDL - Subclass of SDLx::App to meet contract of Op
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 DESCRIPTION
 
@@ -85,12 +88,16 @@ Accepting all the options of make_context
 
 =back
 
-=head1 ATTRIBUTES
+It also provides:
 
-=head2 sdl
+=over 14
+
+=item sdl
 
 The SDL::App object
 
+=back
+
 =head1 AUTHOR
 
 Michael Conrad <mike@nrdvana.net>
